@@ -1,27 +1,28 @@
 #
 # Courier::Error class
 #
-# (C) 2003-2005 Julian Mehnle <julian@mehnle.net>
-# $Id: Error.pm 199 2005-11-10 22:16:37Z julian $
+# (C) 2003-2008 Julian Mehnle <julian@mehnle.net>
+# $Id: Error.pm 210 2008-03-21 19:30:31Z julian $
 #
-##############################################################################
+###############################################################################
 
 =head1 NAME
 
-Courier::Error - A Perl exception class for Perl modules related to the Courier
-MTA
+Courier::Error - Exception class for Perl modules related to the Courier MTA
 
 =cut
 
 package Courier::Error;
 
-=head1 VERSION
+use warnings;
+use strict;
 
-0.17
+use Error;
 
-=cut
+use base 'Error::Simple';
 
-our $VERSION = '0.17';
+use constant TRUE   => (0 == 0);
+use constant FALSE  => not TRUE;
 
 =head1 SYNOPSIS
 
@@ -50,18 +51,6 @@ our $VERSION = '0.17';
 This class is a simple exception class for Perl modules related to the Courier
 MTA.  See L<Error> for detailed instructions on how to use it.
 
-=cut
-
-use warnings;
-use strict;
-
-use Error;
-
-use base qw(Error::Simple);
-
-use constant TRUE   => (0 == 0);
-use constant FALSE  => not TRUE;
-
 =head1 SEE ALSO
 
 For AVAILABILITY, SUPPORT, and LICENSE information, see
@@ -74,5 +63,3 @@ Julian Mehnle <julian@mehnle.net>
 =cut
 
 TRUE;
-
-# vim:tw=79
